==> vaadin-node-maps-20.0.0-20170323.033721-124-sources.jar: org/opennms/features/vaadin/nodemaps/internal/gwt/client/event/ApplicationInitializedEvent.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.nodemaps.internal.gwt.client.event;


public class ApplicationInitializedEvent extends OpenNMSEvent<ApplicationInitializedEventHandler> {
    public static Type<ApplicationInitializedEventHandler> TYPE = new Type<ApplicationInitializedEventHandler>();

    public ApplicationInitializedEvent() {
    }

    @Override
    public com.google.gwt.event.shared.GwtEvent.Type<ApplicationInitializedEventHandler> getAssociatedType() {
        return TYPE;
    }

    @Override
    public void dispatch(final ApplicationInitializedEventHandler handler) {
        handler.onApplicationInitialized(this);
    }

    @Override
    public String toDebugString() {
        return "event: ApplicationInitializedEvent:";
    }
}

==> vaadin-node-maps-24.0.0-sources.jar: org/opennms/features/vaadin/nodemaps/internal/gwt/client/event/ApplicationInitializedEvent.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.nodemaps.internal.gwt.client.event;


public class ApplicationInitializedEvent extends OpenNMSEvent<ApplicationInitializedEventHandler> {
    public static Type<ApplicationInitializedEventHandler> TYPE = new Type<>();

    public ApplicationInitializedEvent() {
    }

    @Override
    public com.google.gwt.event.shared.GwtEvent.Type<ApplicationInitializedEventHandler> getAssociatedType() {
        return TYPE;
    }

    @Override
    public void dispatch(final ApplicationInitializedEventHandler handler) {
        handler.onApplicationInitialized(this);
    }

    @Override
    public String toDebugString() {
        return "event: ApplicationInitializedEvent:";
    }
}
